@@ -6,12 +6,13 @@ var searchData=
   ['cms_5finterface_2eh_3',['cms_interface.h',['../cms__interface_8h.html',1,'']]],
   ['codestream_5fheader_2eh_4',['codestream_header.h',['../codestream__header_8h.html',1,'']]],
   ['color_20encoding_20and_20conversion_5',['Color encoding and conversion',['../group__libjxl__color.html',1,'']]],
-  ['color_5fencoding_6',['color_encoding',['../structJxlColorProfile.html#a7bdca354288b793ca880bc89ea552fd9',1,'JxlColorProfile']]],
+  ['color_5fencoding_6',['color_encoding',['../structJxlColorProfile.html#a7bdca354288b793ca880bc89ea552fd9',1,'JxlColorProfile::color_encoding'],['../structJxlGainMapBundle.html#aac00ed2a96ca32fa5324f7b1573075cd',1,'JxlGainMapBundle::color_encoding']]],
   ['color_5fencoding_2eh_7',['color_encoding.h',['../color__encoding_8h.html',1,'']]],
   ['color_5fspace_8',['color_space',['../structJxlColorEncoding.html#ac835a19d9dc9078284b6ad2e7f975bb7',1,'JxlColorEncoding']]],
   ['common_20api_20concepts_9',['Common API concepts',['../group__libjxl__common.html',1,'']]],
-  ['concepts_10',['Common API concepts',['../group__libjxl__common.html',1,'']]],
-  ['conversion_11',['Color encoding and conversion',['../group__libjxl__color.html',1,'']]],
-  ['crop_5fx0_12',['crop_x0',['../structJxlLayerInfo.html#a900f52caed02a129c0ecef807580ff01',1,'JxlLayerInfo']]],
-  ['crop_5fy0_13',['crop_y0',['../structJxlLayerInfo.html#aec94e2ba532959b7160ff5285d39c8bb',1,'JxlLayerInfo']]]
+  ['compressed_5ficc_2eh_10',['compressed_icc.h',['../compressed__icc_8h.html',1,'']]],
+  ['concepts_11',['Common API concepts',['../group__libjxl__common.html',1,'']]],
+  ['conversion_12',['Color encoding and conversion',['../group__libjxl__color.html',1,'']]],
+  ['crop_5fx0_13',['crop_x0',['../structJxlLayerInfo.html#a900f52caed02a129c0ecef807580ff01',1,'JxlLayerInfo']]],
+  ['crop_5fy0_14',['crop_y0',['../structJxlLayerInfo.html#aec94e2ba532959b7160ff5285d39c8bb',1,'JxlLayerInfo']]]
 ];
